@@ -101,6 +101,7 @@ package Sidef::Deparse::Perl {
                   Sidef::DataTypes::Number::Quaternion    Sidef::Types::Number::Quaternion
                   Sidef::DataTypes::Number::Complex       Sidef::Types::Number::Complex
                   Sidef::DataTypes::Number::Polynomial    Sidef::Types::Number::Polynomial
+                  Sidef::DataTypes::Number::PolynomialMod Sidef::Types::Number::PolynomialMod
                   Sidef::DataTypes::Number::Fraction      Sidef::Types::Number::Fraction
                   Sidef::DataTypes::Range::Range          Sidef::Types::Range::Range
                   Sidef::DataTypes::Range::RangeNumber    Sidef::Types::Range::RangeNumber
@@ -1921,6 +1922,10 @@ HEADER
             }
         }
 
+        if ($code eq '') {
+            $code = '()';
+        }
+
         $code;
     }
 
